@@ -3,7 +3,7 @@
 #'
 #' Input a \eqn{n \times 1} response Y and a \eqn{n \times p} feature matrix X;
 #' the function uses SMLE to retain only a set of \eqn{k<n} features that seem
-#' to be most relevant for a GLM. It thus serves as a pre-processing step for an
+#' to be most related to the response variable. It thus serves as a pre-processing step for an
 #' elaborative analysis. In SMLE, the joint effects between features are naturally
 #' accounted; this makes the screening more reliable. The function uses the
 #' efficient iterative hard thresholding (IHT) algorithm with step parameter
@@ -56,7 +56,7 @@
 #'
 #' @param X The \eqn{n \times p} feature matrix with each column denoting a feature
 #' (covariate) and each row denoting an observation vector. The input should be
-#' the object of "matrix" for numerical data, and "data.frame" for categorical
+#' a "matrix" object for numerical data, and "data.frame" for categorical
 #' data (or a mixture of numerical and categorical data). The algorithm will
 #' treat covariates having class "factor" as categorical data and extend the data
 #' frame dimension by the dummy columns needed for coding the categorical features.
@@ -73,17 +73,17 @@
 #' be used in the screening process. Default is NULL.
 #'
 #' @param U_rate Decreasing rate in tuning step parameter \eqn{u^{-1}} in IHT
-#' algorithm. See details.
+#' algorithm. See Details.
 #'
 #' @param keyset A vector to indicate a set of key features that do not
 #' participate in feature screening and are forced to remain in the model.
-#' Default is null.
+#' Default is NULL
 #'
-#' @param intercept A vector to indicate whether to an intercept be used in
+#' @param intercept A logical flag to indicate whether to an intercept be used in
 #' the model. An intercept will not participate in screening.
 #'
 #' @param group Logical flag for whether to treat the dummy covariates of a
-#' categorical feature as a group. (Only for categorical data, see details).
+#' categorical feature as a group. (Only for categorical data, see Details).
 #' Default is TRUE.
 #'
 #' @param codingtype Coding types for categorical features; default is \code{'DV'}.
@@ -93,7 +93,7 @@
 #' \code{Codingtype = "standard"} conducts standard dummy coding for each level
 #' in comparison with the reference level (first level).
 #'
-#' @param Coef_initial A \eqn{p}-dimensional vector for the initial coefficient 
+#' @param coef_initial A \eqn{p}-dimensional vector for the initial coefficient 
 #' value of the IHT algorithm.  The default is to use Lasso with the sparsity 
 #' closest to \eqn{n-1}. 
 #' 
@@ -103,14 +103,14 @@
 #' a factor of \eqn{\sqrt{J}} is divided from the \eqn{L_2} effect of a group with J members.
 #'
 #' @param standardize Logical flag for feature standardization, prior to
-#' performing (iterative) feature screening.  The resulting coefficients are
-#' always returned on the original scale. Default is \code{standardize=TRUE}.
+#' performing (iterative) feature screening. The resulting coefficients are
+#' always returned on the original scale. 
 #' If features are in the same units already, you might not wish to
-#' standardize.
+#' standardize. Default is \code{standardize=TRUE}.
 #'
 #' @param fast Set to TRUE to enable early stop for SMLE-screening. It may help
 #' to boost the screening efficiency with a little sacrifice of accuracy.
-#' Default is FALSE, see details.
+#' Default is FALSE, see Details.
 #'
 #' @param max_iter Maximum number of iteration steps. Default is 500. 
 #'
@@ -121,8 +121,8 @@
 #'
 #' @param selection A logical flag to indicate whether an elaborate selection
 #' is to be conducted by \code{smle_select} after screening.
-#'  Default is FALSE. If TRUE, the function will return a '\code{selection}' object, 
-#'  see \code{smle_select()} documentation for more details.
+#'  If TRUE, the function will return a '\code{selection}' object, 
+#'  see \code{smle_select()} documentation. Default is FALSE.
 #'
 #' @param ... Additional arguments to be passed to \code{smle_select()} if \code{selection=TRUE}. 
 #' See \code{smle_select()} documentation for more details. 
@@ -134,21 +134,46 @@
 #' Retrieved May 28, 2020.
 #'
 #' Xu, C. and Chen, J. (2014). The Sparse MLE for Ultrahigh-Dimensional Feature
-#' Screening, \emph{Journal of the American Statistical Association}, \bold{109}(507), 1257–1269.
-#'
-#'
+#' Screening, \emph{Journal of the American Statistical Association}, \bold{109}(507), 12571269.
 #'
 #'
 #'
 #' @return
-#' Returns a \code{'smle'} object with
-#' \item{I}{A list of iteration information.
+#' \item{call}{The call that produced this object.}
+#' 
+#' \item{ID_retained}{A vector indicating the features retained after SMLE screening.
+#' The output includes both features retained by SMLE and the features specified in \code{'keyset'}.}
+#'
+#' \item{coef_retained}{The vector of coefficients for the retained features.}
+#'
+#' \item{path_retained}{Iteration path matrix with columns recording the coefficient updates over the IHT procedure.}
+#'
+#' \item{num_retained}{Number of retained features after screening.}
+#'
+#' \item{intercept}{The value, if Intercept = TRUE.}
+#'
+#' \item{steps}{Number of iterations.}
+#'
+#' \item{likelihood_iter}{A list of log-likelihood updates over the IHT iterations }
+#'
+#' \item{Usearch}{Vector giving the number of attempts to find a proper \eqn{u^{-1}} at each iteration step.}
+#' 
+#' \item{family}{A character return of argument.}
+#' 
+#' \item{X,Y}{Original data input.}
+#' 
+#' \item{ctg}{Logical flag whether the input feature matrix includes
+#' categorical features}
+#' 
+#' \item{FD}{A matrix contains feature indices retained at each interaction step.}
+#'
+#' \item{I}{A list containing data objects used by the function during iterations.
 #'
 #' \code{Y}: Same as input Y.
 #'
 #' \code{CM}: Design matrix of class \code{'matrix'} for numeric features (or \code{'data.frame'} with categorical features).
 #'
-#' \code{DM}: A matrix with dummy variable featrues added. (only if there are categorical features).
+#' \code{DM}: A matrix with dummy variable features added. (only if there are categorical features).
 #'
 #' \code{IM}: Iteration path matrix with columns recording IHT coefficient updates.
 #'
@@ -156,52 +181,34 @@
 #'
 #' \code{CI}: Indices of categorical features in \code{CM}.
 #'
-#' \code{Beta0}: Inital value of regression coefficient for IHT.
+#' \code{beta0}: Inital value of regression coefficient for IHT.
 #'
 #' \code{DFI}: Indices of categorical features in \code{IM}.
 #'
 #' \code{codingtype}: Same as input.
+#' 
+#' \code{feature_name}: A list contains the names of selected features.
 #'  }
 #'
-#' \item{ID_Retained}{A vector indicating the features retained after SMLE screening.
-#' The output includes both features retained by SMLE and the features specified in \code{'keyset'}.}
-#'
-#' \item{Coef_Retained}{The vector of coefficients for the retained features.}
-#'
-#' \item{Path_Retained}{Iteration path matrix with columns recording the coefficient updates over the IHT procedure.}
-#'
-#' \item{Num_Retained}{Number of retained featrues after screening.}
-#'
-#' \item{Intercept}{The value, if Intercept = TRUE.}
-#'
-#' \item{steps}{Number of iterations.}
-#'
-#' \item{LH}{A list of log-likelihood updates over the IHT iterations }
-#'
-#' \item{Usearch}{Number of times in searching a proper \eqn{u^{-1}} at each step over the IHT iterations.}
-#'
-#'
-#'
-#'
 #'
 #' @export
-#'
+#' 
 #' @examples
 #'
 #' #Example
-#' set.seed(123.456)
 #' Data<-Gen_Data(n=100, p=5000, family = "gaussian", correlation="ID")
 #' Data
 #' fit<-SMLE(Y=Data$Y, X=Data$X, k=9, family = "gaussian")
 #' fit
 #' summary(fit)
-#' ## The important features we missed:
-#' setdiff(Data$subset_true,fit$ID_Retained)
-#' ## Check if the important featrues are retained.
-#' Data$index %in% fit$ID_Retained
+#' 
+#' # The important features we missed:
+#' setdiff(Data$subset_true,fit$ID_retained)
+#' 
+#' # Check if the important features are retained.
+#' Data$index %in% fit$ID_retained
 #' plot(fit)
-#'
-#'
+#' 
 SMLE <- function (object, ...)
   UseMethod("SMLE")
 
@@ -210,23 +217,25 @@ SMLE <- function (object, ...)
 SMLE.default<-function(object=NULL, X=NULL,Y=NULL,data=NULL, k=NULL, 
                        family=c("gaussian","binomial","poisson"),
                        categorical = NULL , keyset = NULL, intercept = TRUE ,
-                       group = TRUE , codingtype = NULL , Coef_initial=NULL,
+                       group = TRUE , codingtype = NULL , coef_initial=NULL,
                        max_iter = 500 , tol = 0.01 ,selection = F ,
                        standardize = TRUE , fast = FALSE , U_rate=0.5 ,
                        penalize_mod = TRUE,...){
-
+  
   #-------Input preprocess-------
-
+  
   family<-match.arg(family)
-
+  
   cl<-match.call()
   cl[[1]] <- as.name("SMLE")
   
   ####Input object is a design matrix
   if(is.null(Y)&is.null(object)){stop("Response required")}
-  if(is.null(X)&is.null(data)){stop("Featrue Matrix required")}
+  if(is.null(X)&is.null(data)){stop("Feature Matrix required")}
   if(is.null(Y)&!is.null(object)){Y<-object}
   if(is.null(X)&!is.null(data)){X<-data}
+  
+  Data_X<-X
   ####
   if(is.null(k)){
     
@@ -238,32 +247,32 @@ SMLE.default<-function(object=NULL, X=NULL,Y=NULL,data=NULL, k=NULL,
     Ci<-(1:dim(X)[2])[sapply(X,is.factor)]
     
     if( any(Ci) ){
-    
-        categorical = TRUE
-    
-        }else{
-        
-          categorical= FALSE
-        
-          X<- as.matrix(X, ncol=dim(X)[2])
-        
-          }
-    
+      
+      categorical = TRUE
+      
+    }else{
+      
+      categorical= FALSE
+      
+      X<- as.matrix(X, ncol=dim(X)[2])
+      
     }
-
-
-  #-------Run Algoriathm------
-
-  if(!is.null(Coef_initial)){
-
-    stopifnot(length(Coef_initial)==dim(X)[2])
+    
   }
-
-
+  
+  
+  #-------Run Algoriathm------
+  
+  if(!is.null(coef_initial)){
+    
+    stopifnot(length(coef_initial)==dim(X)[2])
+  }
+  
+  
   if(categorical == TRUE){
     
     Ci<-(1:dim(X)[2])[sapply(X,is.factor)]
-  
+    
     if(is.null( codingtype )){codingtype<-"DV"}
     
     if(group==FALSE &codingtype!="all"){stop("codingtype should be 'all' when group = FALSE")}
@@ -288,7 +297,7 @@ SMLE.default<-function(object=NULL, X=NULL,Y=NULL,data=NULL, k=NULL,
         Xs <- data.frame( X[,1] , Xs )
         
         colnames(Xs)<-c(names(X)[1],name)
-
+        
       }else if( Ci[i]>dim(Xs)[2]){
         
         name<-dimnames(Xs)[[2]]
@@ -296,7 +305,7 @@ SMLE.default<-function(object=NULL, X=NULL,Y=NULL,data=NULL, k=NULL,
         Xs<-data.frame(Xs,X[,Ci[i]])
         
         colnames(Xs)<-c(name,names(X)[Ci[i]])
-
+        
       }else{ 
         
         name<- dimnames(Xs)[[2]]
@@ -304,27 +313,27 @@ SMLE.default<-function(object=NULL, X=NULL,Y=NULL,data=NULL, k=NULL,
         Xs<-data.frame(Xs[,1:Ci[i]-1],X[,Ci[i]],Xs[,Ci[i]:dim(Xs)[2]])
         
         colnames(Xs)<-c(name[1:Ci[i]-1],names(X)[Ci[i]],name[Ci[i]:(length(name))])
-
-        }
+        
+      }
       
     }
     
     
     
-
-
+    
+    
     fit<- ctg_fit(Y, Xs, k, family, categorical, keyset, Ci, max_iter, tol, fast,
                   
                   intercept, group, codingtype, penalize_mod,
                   
-                  U_rate, X_mean = X_mean, X_sd=X_sd, Coef_initial, cl)
-
+                  U_rate, X_mean = X_mean, X_sd=X_sd, coef_initial, cl,Data_X=Data_X)
+    
     return(fit)
-
+    
   }else{
-  
+    
     X_mean = NULL;X_sd=NULL;Xs<-X
-
+    
     if(standardize== TRUE){
       
       S<-Standardize(X)
@@ -334,30 +343,30 @@ SMLE.default<-function(object=NULL, X=NULL,Y=NULL,data=NULL, k=NULL,
       X_mean<-S$X_mean
       
       X_sd<- S$X_sd
-
+      
     }
     
     fit<-SMLE_fit(Y=Y, X= Xs, k= k, family=family, keyset=keyset,
-                
-                intercept=intercept, max_iter =max_iter, tol =tol, fast =fast,
-                
-                U_rate=U_rate, X_mean = X_mean, X_sd=X_sd, Coef_initial=Coef_initial)
+                  
+                  intercept=intercept, max_iter =max_iter, tol =tol, fast =fast,
+                  
+                  U_rate=U_rate, X_mean = X_mean, X_sd=X_sd, coef_initial=coef_initial, Data_X=Data_X)
   }
-
+  
   #------Adding method-----
-
+  
   fit$call=cl
-
+  
   class(fit)="smle"
-
+  
   #-----Stage II ---------
   if(selection==F){
-
+    
     return(fit)
-
-    }else{
-
-  return(smle_select(fit,...))
+    
+  }else{
+    
+    return(smle_select(fit,...))
   }
 }
 
@@ -366,7 +375,7 @@ SMLE.default<-function(object=NULL, X=NULL,Y=NULL,data=NULL, k=NULL,
 #' @param data an optional data frame, list or environment (or object coercible by as.data.frame to a data frame) containing the variables in the model. 
 #' @export
 SMLE.formula<- function (object, data, categorical=NULL,...) {
-
+  
   ## keep call (of generic)
   cl <- match.call()
   cl[[1]] <- as.name("SMLE")
@@ -404,15 +413,15 @@ SMLE.formula<- function (object, data, categorical=NULL,...) {
       ans <- SMLE(Y=y, X=x, ...)
     }
   }
-
+  
   
   ## done
   ans
 }
 
-SMLE_fit<-function(Y , X, k, family="gaussian", keyset=NULL,
+SMLE_fit<-function(Y,X, k, family="gaussian", keyset=NULL,
                    intercept=TRUE, max_iter=500, tol=0.01, fast=FALSE,
-                   U_rate=0.5,X_mean=NULL,X_sd=NULL,Coef_initial=NULL){
+                   U_rate=0.5,X_mean=NULL,X_sd=NULL,coef_initial=NULL, Data_X){
   
   LH<-rep(0,max_iter)
   
@@ -420,7 +429,7 @@ SMLE_fit<-function(Y , X, k, family="gaussian", keyset=NULL,
   
   n<-dim(X)[1];p<-dim(X)[2]
   
-  if( is.null( Coef_initial ) ){
+  if( is.null( coef_initial ) ){
     
     fit_pre<-glmnet(x=X,y=Y,family=family)
     
@@ -428,7 +437,7 @@ SMLE_fit<-function(Y , X, k, family="gaussian", keyset=NULL,
     
   }else{ 
     
-    Beta0 <- Coef_initial }
+    Beta0 <- coef_initial }
   
   FD<-NULL
   
@@ -469,7 +478,7 @@ SMLE_fit<-function(Y , X, k, family="gaussian", keyset=NULL,
   
   beta_path<-as.matrix(Beta0,nrow=pp,ncol=1)
   
-  I<-list(CM=X,Y=Y,IM=X_iter,Beta0=Beta0,family=family)
+  I<-list(CM=X,Y=Y,IM=X_iter,beta0=Beta0,family=family)
   
   pp<-p+intercept
   
@@ -477,7 +486,7 @@ SMLE_fit<-function(Y , X, k, family="gaussian", keyset=NULL,
   
   Xs_0 <- X_iter[, ID_None0]
   
-  if(!is.null(Coef_initial) & sum(Coef_initial!=0)==0){ 
+  if(!is.null(coef_initial) & sum(coef_initial!=0)==0){ 
     
     R_0<-matrix(0, ncol=1, nrow=n) 
     
@@ -497,7 +506,7 @@ SMLE_fit<-function(Y , X, k, family="gaussian", keyset=NULL,
   V_0<-crossprod(X_iter,Y - R_0)
   
   
-  if(!is.null(Coef_initial) & sum(Coef_initial!=0)==0){
+  if(!is.null(coef_initial) & sum(coef_initial!=0)==0){
     
     if(intercept==T){
       
@@ -633,7 +642,7 @@ SMLE_fit<-function(Y , X, k, family="gaussian", keyset=NULL,
   
   if( intercept == T ){
     
-    #rescale beta_path
+    #resale beta_path
     
     beta_path<-beta_path[-1,]             
     
@@ -662,33 +671,36 @@ SMLE_fit<-function(Y , X, k, family="gaussian", keyset=NULL,
     Intercept_value = NULL
     
   }
+  feature_name =NULL
   
+  if( !is.null(colnames(Data_X))){ feature_name=colnames(Data_X)[ID_None0]}
   
-  
-  
-  fit<-list(I=I,X=I$CM, Y=I$Y,
+  fit<-list(data_info=I,X=Data_X, Y=Y, 
             
             keyset = keyset, family = family, k = k,
             
-            Intercept=Intercept_value,
+            intercept=Intercept_value,
             
             steps = i,
             
-            LH=LH[1:i],
+            likelihood_iter=LH[1:i],
             
-            Usearch=number_of_Ucheck[1:i],
+            usearch=number_of_Ucheck[1:i],
             
-            Path_Retained  = beta_path,
+            path_retained  = beta_path,
             
-            Num_Retained   = length(ID_None0),
+            num_retained   = length(ID_None0),
             
-            ID_Retained    = ID_None0,
+            ID_retained    = ID_None0,
             
-            Coef_Retained  = coef_None0,
+            coef_retained  = coef_None0,
             
-            FD=FD, ctg = FALSE, Coef_dist=Coef_dist,
+            FD=FD, ctg = FALSE, coef_dist=Coef_dist,
+            
+            feature_name =feature_name,
             
             fast=fast
   )
 }
 
+
